aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2018-08-06 13:59:21 +0300
committerRoy Ben-Shabat <Roy@Twine-s.com>2018-08-06 13:59:21 +0300
commite852b5a6bf11f8bf85a8f59986da170364a3319f (patch)
tree7ed02bfe8f0f5272687a69edd6193acc6c1879fc
parentcd92ad2dc4a8df75c1b955757b07c796b064b7e2 (diff)
downloadTango-e852b5a6bf11f8bf85a8f59986da170364a3319f.tar.gz
Tango-e852b5a6bf11f8bf85a8f59986da170364a3319f.zip
Machine Studio v2.4
-rw-r--r--Software/DB/Tango.mdfbin75497472 -> 75497472 bytes
-rw-r--r--Software/DB/Tango_log.ldfbin1835008 -> 1835008 bytes
-rw-r--r--Software/PMR/Messages/Diagnostics/ValueComponent.proto3
-rw-r--r--Software/PMR/Messages/Hardware/HardwareBlowerType.proto4
-rw-r--r--Software/PMR/Messages/Hardware/HardwareBreakSensorType.proto4
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs1
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/JobView.xaml59
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.HardwareDesigner/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Logging/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.MachineDesigner/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Synchronization/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/ControllerElementEditor.xaml2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/MultiGraphElementEditor.xaml10
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/SingleGraphElementEditor.xaml10
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/ControllerTemplate.xaml4
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/MultiGraphTemplate.xaml2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/SingleGraphTemplate.xaml2
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/MultiGraphItem.cs35
-rw-r--r--Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/SingleGraphItem.cs37
-rw-r--r--Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/TFS/TeamFoundationServiceExtendedClient.cs4
-rw-r--r--Software/Visual_Studio/SideChains/RealTimeGraphEx/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/SideChains/Tango.AutoComplete/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.BL/EntitiesExtensions/BrushStop.cs10
-rw-r--r--Software/Visual_Studio/Tango.BL/Enumerations/HardwareBlowerTypes.cs6
-rw-r--r--Software/Visual_Studio/Tango.BL/Enumerations/HardwareBreakSensorTypes.cs6
-rw-r--r--Software/Visual_Studio/Tango.BL/Enumerations/TechControllers.cs6
-rw-r--r--Software/Visual_Studio/Tango.BL/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.CircularGauge/CircularGaugeControl.cs39
-rw-r--r--Software/Visual_Studio/Tango.CircularGauge/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.CodeGeneration/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.ColorPicker/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Core/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.DAL.Local/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.DAL.Remote/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.DragAndDrop/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Editors/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Emulations/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Integration/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Logging/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.PMR/Common/ErrorCode.cs11
-rw-r--r--Software/Visual_Studio/Tango.PMR/Diagnostics/ValueComponent.cs10
-rw-r--r--Software/Visual_Studio/Tango.PMR/Hardware/HardwareBlowerType.cs8
-rw-r--r--Software/Visual_Studio/Tango.PMR/Hardware/HardwareBreakSensorType.cs10
-rw-r--r--Software/Visual_Studio/Tango.PMR/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Protobuf/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Scripting/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Serialization/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Settings/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.SharedUI/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Synchronization/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.TFS/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Transport/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Tango.Video/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Utilities/Tango.ILMerge.UI/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Utilities/Tango.Stubs.Installer/Tango.Stubs.Installer.vdproj164
-rw-r--r--Software/Visual_Studio/Utilities/Tango.Stubs.UI/Properties/AssemblyInfo.cs2
-rw-r--r--Software/Visual_Studio/Utilities/Tango.UITests/Properties/AssemblyInfo.cs2
61 files changed, 294 insertions, 223 deletions
diff --git a/Software/DB/Tango.mdf b/Software/DB/Tango.mdf
index 36c0f2dc0..ace8d83f3 100644
--- a/Software/DB/Tango.mdf
+++ b/Software/DB/Tango.mdf
Binary files differ
diff --git a/Software/DB/Tango_log.ldf b/Software/DB/Tango_log.ldf
index 4d03056fb..db5901290 100644
--- a/Software/DB/Tango_log.ldf
+++ b/Software/DB/Tango_log.ldf
Binary files differ
diff --git a/Software/PMR/Messages/Diagnostics/ValueComponent.proto b/Software/PMR/Messages/Diagnostics/ValueComponent.proto
index a6bc1a50a..675a57245 100644
--- a/Software/PMR/Messages/Diagnostics/ValueComponent.proto
+++ b/Software/PMR/Messages/Diagnostics/ValueComponent.proto
@@ -22,4 +22,7 @@ enum ValueComponent
//Heater 2 Temperature (Min = 0, Max = 100)
Heater2Temp = 1;
+ //Blower Voltage (Min = 0, Max = 10000)
+ BlowerVoltage = 2;
+
}
diff --git a/Software/PMR/Messages/Hardware/HardwareBlowerType.proto b/Software/PMR/Messages/Hardware/HardwareBlowerType.proto
index 44980e836..b28eab584 100644
--- a/Software/PMR/Messages/Hardware/HardwareBlowerType.proto
+++ b/Software/PMR/Messages/Hardware/HardwareBlowerType.proto
@@ -16,7 +16,7 @@ option java_package = "com.twine.tango.pmr.hardware";
enum HardwareBlowerType
{
- //Standard Blower
- StandardBlower = 0;
+ //Default Blower
+ DefaultBlower = 0;
}
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Properties/AssemblyInfo.cs
index da66a79d8..104fe419e 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Developer Module")]
-[assembly: AssemblyVersion("2.0.10.1828")]
+[assembly: AssemblyVersion("2.0.12.1347")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs
index 85480a4b8..1edbce641 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/ViewModels/MainViewVM.cs
@@ -1647,6 +1647,7 @@ namespace Tango.MachineStudio.Developer.ViewModels
{
LogManager.LogFormat("Adding new segment to job {0}...", ActiveJob.Name);
Segment seg = new Segment();
+ seg.Job = ActiveJob;
seg.Name = "Untitled Segment";
seg.Length = 10;
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/JobView.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/JobView.xaml
index d6652b38d..6d10e910e 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/JobView.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Developer/Views/JobView.xaml
@@ -550,7 +550,7 @@
<StackPanel Margin="5" Width="140">
<StackPanel Orientation="Horizontal">
<Image Source="../Images/ruler.png" Width="32"></Image>
- <TextBlock VerticalAlignment="Center" Margin="5 0 0 0" FontSize="10">Length</TextBlock>
+ <TextBlock VerticalAlignment="Center" Margin="5 0 0 0" FontSize="10">Segment Length</TextBlock>
</StackPanel>
<mahapps:NumericUpDown FontSize="{StaticResource NumbersFontSize}" HideUpDownButtons="True" Width="90" HorizontalAlignment="Left" FontFamily="{StaticResource digital-7}" StringFormat="{}{0:N1} m" Margin="0 2 0 0" Minimum="1" Maximum="10000" InterceptArrowKeys="True" Background="Transparent" BorderThickness="0 0 0 1" BorderBrush="DimGray" InterceptMouseWheel="True" HasDecimals="True" HorizontalContentAlignment="Left" Value="{Binding SelectedSegment.Length,Mode=TwoWay}"></mahapps:NumericUpDown>
</StackPanel>
@@ -721,33 +721,40 @@
<DataTrigger Binding="{Binding ColorSpace.Name}" Value="Volume">
<Setter Property="Content">
<Setter.Value>
- <StackPanel VerticalAlignment="Center">
- <ItemsControl ItemsSource="{Binding LiquidVolumes}" VerticalAlignment="Center">
- <ItemsControl.ItemsPanel>
- <ItemsPanelTemplate>
- <StackPanel VerticalAlignment="Center" Orientation="Horizontal" IsItemsHost="True"></StackPanel>
- </ItemsPanelTemplate>
- </ItemsControl.ItemsPanel>
- <ItemsControl.ItemTemplate>
- <DataTemplate>
- <ContentControl Focusable="False" Style="{StaticResource numberBorder}" Width="60" Height="60" Margin="10 0 0 0">
- <ContentControl.Foreground>
- <SolidColorBrush Color="{Binding IdsPack.LiquidType.Color,Converter={StaticResource ColorToIntegerConverter}}"></SolidColorBrush>
- </ContentControl.Foreground>
- <mahapps:NumericUpDown FontSize="{StaticResource NumbersFontSize}" FontFamily="{StaticResource digital-7}" HorizontalAlignment="Center" Value="{Binding Volume, Mode=TwoWay}" Background="Transparent" Width="40" StringFormat="0" HideUpDownButtons="True" Minimum="0" Maximum="1000" InterceptArrowKeys="True" BorderThickness="0" InterceptMouseWheel="True" HasDecimals="True" HorizontalContentAlignment="Center">
- <mahapps:NumericUpDown.Resources>
- <StaticResource ResourceKey="SelectAllTextBoxResource"></StaticResource>
- </mahapps:NumericUpDown.Resources>
- </mahapps:NumericUpDown>
- </ContentControl>
- </DataTemplate>
- </ItemsControl.ItemTemplate>
- </ItemsControl>
+ <StackPanel Orientation="Horizontal" HorizontalAlignment="Left">
+ <StackPanel VerticalAlignment="Center">
+ <ItemsControl ItemsSource="{Binding LiquidVolumes}" VerticalAlignment="Center">
+ <ItemsControl.ItemsPanel>
+ <ItemsPanelTemplate>
+ <StackPanel VerticalAlignment="Center" Orientation="Horizontal" IsItemsHost="True"></StackPanel>
+ </ItemsPanelTemplate>
+ </ItemsControl.ItemsPanel>
+ <ItemsControl.ItemTemplate>
+ <DataTemplate>
+ <ContentControl Focusable="False" Style="{StaticResource numberBorder}" Width="60" Height="60" Margin="10 0 0 0">
+ <ContentControl.Foreground>
+ <SolidColorBrush Color="{Binding IdsPack.LiquidType.Color,Converter={StaticResource ColorToIntegerConverter}}"></SolidColorBrush>
+ </ContentControl.Foreground>
+ <mahapps:NumericUpDown FontSize="{StaticResource NumbersFontSize}" FontFamily="{StaticResource digital-7}" HorizontalAlignment="Center" Value="{Binding Volume, Mode=TwoWay}" Background="Transparent" Width="40" StringFormat="0" HideUpDownButtons="True" Minimum="0" Maximum="1000" InterceptArrowKeys="True" BorderThickness="0" InterceptMouseWheel="True" HasDecimals="True" HorizontalContentAlignment="Center">
+ <mahapps:NumericUpDown.Resources>
+ <StaticResource ResourceKey="SelectAllTextBoxResource"></StaticResource>
+ </mahapps:NumericUpDown.Resources>
+ </mahapps:NumericUpDown>
+ </ContentControl>
+ </DataTemplate>
+ </ItemsControl.ItemTemplate>
+ </ItemsControl>
- <StackPanel Orientation="Horizontal" Margin="30 10 0 0" Height="16" Visibility="{Binding IsLiquidVolumesOutOfRange,Converter={StaticResource BooleanToVisibilityConverter}}">
- <materialDesign:PackIcon Kind="Alert" Foreground="#FFAC3C" />
- <TextBlock Margin="5 0 0 0" Foreground="#FFAC3C">Liquid volumes exceeds the maximum range for color conversion!</TextBlock>
+ <StackPanel Orientation="Horizontal" Margin="30 10 0 0" Height="16" Visibility="{Binding IsLiquidVolumesOutOfRange,Converter={StaticResource BooleanToVisibilityConverter}}">
+ <materialDesign:PackIcon Kind="Alert" Foreground="#FFAC3C" />
+ <TextBlock Margin="5 0 0 0" Foreground="#FFAC3C">Liquid volumes exceeds the maximum range for color conversion!</TextBlock>
+ </StackPanel>
</StackPanel>
+
+ <TextBlock VerticalAlignment="Center" Margin="40 0 0 0" FontSize="16" FontStyle="Italic" Foreground="Gray">
+ <Run>Total:</Run>
+ <Run Text="{Binding LiquidVolumesSum,Mode=OneWay,StringFormat=0}"></Run>
+ </TextBlock>
</StackPanel>
</Setter.Value>
</Setter>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.HardwareDesigner/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.HardwareDesigner/Properties/AssemblyInfo.cs
index a77506fd7..f6d950a60 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.HardwareDesigner/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.HardwareDesigner/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Hardware Designer Module")]
-[assembly: AssemblyVersion("2.0.6.1407")]
+[assembly: AssemblyVersion("2.0.7.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Logging/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Logging/Properties/AssemblyInfo.cs
index 7c1a4b38b..e02b63000 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Logging/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Logging/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Logging Module")]
-[assembly: AssemblyVersion("2.0.11.1933")]
+[assembly: AssemblyVersion("2.0.12.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.MachineDesigner/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.MachineDesigner/Properties/AssemblyInfo.cs
index ec4ca0566..c930f533e 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.MachineDesigner/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.MachineDesigner/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Machine Designer Module")]
-[assembly: AssemblyVersion("2.0.6.1407")]
+[assembly: AssemblyVersion("2.0.7.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Synchronization/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Synchronization/Properties/AssemblyInfo.cs
index 6a34bd5ad..884170a37 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Synchronization/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Synchronization/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Synchronization Module")]
-[assembly: AssemblyVersion("2.0.7.1304")]
+[assembly: AssemblyVersion("2.0.8.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/ControllerElementEditor.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/ControllerElementEditor.xaml
index 5cffffc90..346c0067b 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/ControllerElementEditor.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/ControllerElementEditor.xaml
@@ -82,7 +82,7 @@
</visuals:Fader>
- <TextBlock HorizontalAlignment="Left" VerticalAlignment="Top" FontFamily="../Fonts/#digital-7" TextAlignment="Right" Margin="-50 10 0 0" FontSize="30" Text="{Binding ElementName=fader,Path=Value,StringFormat=0.0,FallbackValue=100}">
+ <TextBlock HorizontalAlignment="Left" VerticalAlignment="Top" FontFamily="../Fonts/#digital-7" TextAlignment="Right" Margin="-80 10 0 0" FontSize="30" Text="{Binding ElementName=fader,Path=Value,StringFormat=0.0,FallbackValue=100}">
<TextBlock.Foreground>
<SolidColorBrush Color="{Binding Color,FallbackValue=White}" />
</TextBlock.Foreground>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/MultiGraphElementEditor.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/MultiGraphElementEditor.xaml
index 8e064e30c..9bc22d0f6 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/MultiGraphElementEditor.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/MultiGraphElementEditor.xaml
@@ -33,14 +33,8 @@
<controls:RealTimeGraphMultiControl x:Name="InnerGraph" UseAutoRange="{Binding UseAutoRange}" IsHitTestVisible="{Binding RelativeSource={RelativeSource AncestorType=local:ElementsEditor},Path=IsEditable,Converter={StaticResource BooleanInverseConverter}}" x:FieldModifier="public" EnableToolBar="False" SensorName="{Binding TechMonitor.Description}" SensorUnits="{Binding TechMonitor.Units}">
<controls:RealTimeGraphMultiControl.Style>
<Style TargetType="controls:RealTimeGraphMultiControl">
- <Setter Property="Minimum" Value="{Binding TechMonitor.Min,Mode=TwoWay}"></Setter>
- <Setter Property="Maximum" Value="{Binding TechMonitor.Max,Mode=TwoWay}"></Setter>
- <Style.Triggers>
- <DataTrigger Binding="{Binding UseMinMax}" Value="True">
- <Setter Property="Minimum" Value="{Binding Min,Mode=TwoWay}"></Setter>
- <Setter Property="Maximum" Value="{Binding Max,Mode=TwoWay}"></Setter>
- </DataTrigger>
- </Style.Triggers>
+ <Setter Property="Minimum" Value="{Binding Min,Mode=TwoWay}"></Setter>
+ <Setter Property="Maximum" Value="{Binding Max,Mode=TwoWay}"></Setter>
</Style>
</controls:RealTimeGraphMultiControl.Style>
</controls:RealTimeGraphMultiControl>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/SingleGraphElementEditor.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/SingleGraphElementEditor.xaml
index 89da5be7c..16f94b251 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/SingleGraphElementEditor.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Editors/SingleGraphElementEditor.xaml
@@ -33,14 +33,8 @@
<controls:RealTimeGraphControl x:Name="InnerGraph" UseAutoRange="{Binding UseAutoRange}" IsHitTestVisible="{Binding RelativeSource={RelativeSource AncestorType=local:ElementsEditor},Path=IsEditable,Converter={StaticResource BooleanInverseConverter}}" x:FieldModifier="public" EnableToolBar="False" SensorName="{Binding TechMonitor.Description}" Color="{Binding Color,Mode=OneWay}" SensorUnits="{Binding TechMonitor.Units}">
<controls:RealTimeGraphControl.Style>
<Style TargetType="controls:RealTimeGraphControl">
- <Setter Property="Minimum" Value="{Binding TechMonitor.Min,Mode=TwoWay}"></Setter>
- <Setter Property="Maximum" Value="{Binding TechMonitor.Max,Mode=TwoWay}"></Setter>
- <Style.Triggers>
- <DataTrigger Binding="{Binding UseMinMax}" Value="True">
- <Setter Property="Minimum" Value="{Binding Min,Mode=TwoWay}"></Setter>
- <Setter Property="Maximum" Value="{Binding Max,Mode=TwoWay}"></Setter>
- </DataTrigger>
- </Style.Triggers>
+ <Setter Property="Minimum" Value="{Binding Min,Mode=TwoWay}"></Setter>
+ <Setter Property="Maximum" Value="{Binding Max,Mode=TwoWay}"></Setter>
</Style>
</controls:RealTimeGraphControl.Style>
</controls:RealTimeGraphControl>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Properties/AssemblyInfo.cs
index f19848756..0a28fdd26 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Technician Module")]
-[assembly: AssemblyVersion("2.0.8.1304")]
+[assembly: AssemblyVersion("2.0.10.1347")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/ControllerTemplate.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/ControllerTemplate.xaml
index ffc726abf..2f5934a76 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/ControllerTemplate.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/ControllerTemplate.xaml
@@ -35,7 +35,9 @@
<colorPicker:ColorCanvas SelectedColor="{Binding Color,Mode=TwoWay}" Background="Transparent" />
</Viewbox>
- <TextBlock FontSize="10" Margin="0 20 0 0"><Run>Optimal Range:</Run> <Run Text="{Binding OptimalRangeMinimum,StringFormat=0.0}"></Run><Run> to </Run><Run Text="{Binding OptimalRangeMaximum,StringFormat=0.0}"></Run></TextBlock>
+ <TextBlock FontSize="10" Margin="0 20 0 0"><Run>Optimal Range:</Run> <Run Text="{Binding OptimalRangeMinimum,StringFormat=0.0}"></Run>
+ <Run>to</Run>
+ <Run Text="{Binding OptimalRangeMaximum,StringFormat=0.0}"></Run></TextBlock>
<mahapps:RangeSlider Margin="0 5 0 0" Minimum="{Binding TechController.Min}" Maximum="{Binding TechController.Max}" LowerValue="{Binding OptimalRangeMinimum}" UpperValue="{Binding OptimalRangeMaximum}"></mahapps:RangeSlider>
</StackPanel>
</GroupBox>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/MultiGraphTemplate.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/MultiGraphTemplate.xaml
index 0e2afcf53..2f5e677c4 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/MultiGraphTemplate.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/MultiGraphTemplate.xaml
@@ -45,7 +45,7 @@
<mahapps:NumericUpDown HasDecimals="True" HorizontalContentAlignment="Center" BorderBrush="Gainsboro" Foreground="Gray" Margin="0 5 0 0" Minimum="{Binding Min}" Maximum="1000000" Value="{Binding Max,Mode=TwoWay}"></mahapps:NumericUpDown>
</StackPanel>
</UniformGrid>
- <CheckBox Margin="0 10 0 0" IsChecked="{Binding UseMinMax,Converter={StaticResource BooleanInverseConverter}}">Use default ranges</CheckBox>
+ <Button Margin="0 10 0 0" Command="{Binding ResetMinMaxToDefaultCommand}" Style="{StaticResource MaterialDesignFlatButton}">Set To Default</Button>
</StackPanel>
<CheckBox IsChecked="{Binding UseAutoRange}">Use auto ranges</CheckBox>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/SingleGraphTemplate.xaml b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/SingleGraphTemplate.xaml
index 5c090d4b5..4acbd2fc1 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/SingleGraphTemplate.xaml
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/PropertiesTemplates/SingleGraphTemplate.xaml
@@ -45,7 +45,7 @@
<mahapps:NumericUpDown HasDecimals="True" HorizontalContentAlignment="Center" BorderBrush="Gainsboro" Foreground="Gray" Margin="0 5 0 0" Minimum="{Binding Min}" Maximum="1000000" Value="{Binding Max,Mode=TwoWay}"></mahapps:NumericUpDown>
</StackPanel>
</UniformGrid>
- <CheckBox Margin="0 10 0 0" IsChecked="{Binding UseMinMax,Converter={StaticResource BooleanInverseConverter}}">Use default ranges</CheckBox>
+ <Button Margin="0 10 0 0" Command="{Binding ResetMinMaxToDefaultCommand}" Style="{StaticResource MaterialDesignFlatButton}">Set To Default</Button>
</StackPanel>
<CheckBox IsChecked="{Binding UseAutoRange}">Use auto ranges</CheckBox>
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/MultiGraphItem.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/MultiGraphItem.cs
index d4bdfb7b2..5a3bd0327 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/MultiGraphItem.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/MultiGraphItem.cs
@@ -79,16 +79,6 @@ namespace Tango.MachineStudio.Technician.TechItems
set { _max = value; RaisePropertyChangedAuto(); }
}
- private bool _useMinMax;
- /// <summary>
- /// Gets or sets a value indicating whether [use minimum maximum].
- /// </summary>
- public bool UseMinMax
- {
- get { return _useMinMax; }
- set { _useMinMax = value; RaisePropertyChangedAuto(); }
- }
-
private bool _useAutoRange;
/// <summary>
/// Gets or sets a value indicating whether [use automatic range].
@@ -144,6 +134,12 @@ namespace Tango.MachineStudio.Technician.TechItems
public RelayCommand ToggleRecordingCommand { get; set; }
/// <summary>
+ /// Gets or sets the reset minimum maximum to default command.
+ /// </summary>
+ [XmlIgnore]
+ public RelayCommand ResetMinMaxToDefaultCommand { get; set; }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="MultiGraphItem"/> class.
/// </summary>
public MultiGraphItem() : base()
@@ -166,6 +162,24 @@ namespace Tango.MachineStudio.Technician.TechItems
});
ToggleRecordingCommand = new RelayCommand(ToggleRecording);
+
+ ResetMinMaxToDefaultCommand = new RelayCommand(() =>
+ {
+ if (TechMonitor != null)
+ {
+ Min = TechMonitor.Min;
+ Max = TechMonitor.Max;
+ }
+ });
+ }
+
+ private void OnTechMonitorChanged()
+ {
+ if (TechMonitor != null)
+ {
+ Min = TechMonitor.Min;
+ Max = TechMonitor.Max;
+ }
}
private void _timer_Tick(object sender, EventArgs e)
@@ -210,7 +224,6 @@ namespace Tango.MachineStudio.Technician.TechItems
cloned.TechMonitor = TechMonitor;
cloned.Min = Min;
cloned.Max = Max;
- cloned.UseMinMax = UseMinMax;
cloned.UseAutoRange = UseAutoRange;
return cloned;
}
diff --git a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/SingleGraphItem.cs b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/SingleGraphItem.cs
index c175f1138..aa404b215 100644
--- a/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/SingleGraphItem.cs
+++ b/Software/Visual_Studio/MachineStudio/Modules/Tango.MachineStudio.Technician/TechItems/SingleGraphItem.cs
@@ -50,6 +50,8 @@ namespace Tango.MachineStudio.Technician.TechItems
ItemGuid = value != null ? value.Guid : null;
TechName = _techMonitor != null ? _techMonitor.Description : null;
+
+ OnTechMonitorChanged();
}
}
@@ -79,16 +81,6 @@ namespace Tango.MachineStudio.Technician.TechItems
set { _max = value; RaisePropertyChangedAuto(); }
}
- private bool _useMinMax;
- /// <summary>
- /// Gets or sets a value indicating whether [use minimum maximum].
- /// </summary>
- public bool UseMinMax
- {
- get { return _useMinMax; }
- set { _useMinMax = value; RaisePropertyChangedAuto(); }
- }
-
private bool _useAutoRange;
/// <summary>
/// Gets or sets a value indicating whether [use automatic range].
@@ -144,6 +136,12 @@ namespace Tango.MachineStudio.Technician.TechItems
public RelayCommand ToggleRecordingCommand { get; set; }
/// <summary>
+ /// Gets or sets the reset minimum maximum to default command.
+ /// </summary>
+ [XmlIgnore]
+ public RelayCommand ResetMinMaxToDefaultCommand { get; set; }
+
+ /// <summary>
/// Initializes a new instance of the <see cref="SingleGraphItem"/> class.
/// </summary>
public SingleGraphItem() : base()
@@ -166,6 +164,15 @@ namespace Tango.MachineStudio.Technician.TechItems
});
ToggleRecordingCommand = new RelayCommand(ToggleRecording);
+
+ ResetMinMaxToDefaultCommand = new RelayCommand(() =>
+ {
+ if (TechMonitor != null)
+ {
+ Min = TechMonitor.Min;
+ Max = TechMonitor.Max;
+ }
+ });
}
private void _timer_Tick(object sender, EventArgs e)
@@ -200,6 +207,15 @@ namespace Tango.MachineStudio.Technician.TechItems
TechMonitor = techMonitor;
}
+ private void OnTechMonitorChanged()
+ {
+ if (TechMonitor != null)
+ {
+ Min = TechMonitor.Min;
+ Max = TechMonitor.Max;
+ }
+ }
+
/// <summary>
/// Clones this instance.
/// </summary>
@@ -210,7 +226,6 @@ namespace Tango.MachineStudio.Technician.TechItems
cloned.TechMonitor = TechMonitor;
cloned.Min = Min;
cloned.Max = Max;
- cloned.UseMinMax = UseMinMax;
cloned.UseAutoRange = UseAutoRange;
return cloned;
}
diff --git a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/Properties/AssemblyInfo.cs
index 7ce7f6399..a8f1af061 100644
--- a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.Common/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Machine Studio Common Components")]
-[assembly: AssemblyVersion("2.0.19.1933")]
+[assembly: AssemblyVersion("2.0.20.1034")]
[assembly: ComVisible(false)]
[assembly:ThemeInfo(
diff --git a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/Properties/AssemblyInfo.cs b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/Properties/AssemblyInfo.cs
index 2d1a79111..ea359e8bb 100644
--- a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/Properties/AssemblyInfo.cs
@@ -4,5 +4,5 @@ using System.Runtime.InteropServices;
[assembly: System.Windows.ThemeInfo(System.Windows.ResourceDictionaryLocation.None, System.Windows.ResourceDictionaryLocation.SourceAssembly)]
[assembly: AssemblyTitle("Tango - Machine Studio")]
-[assembly: AssemblyVersion("2.2.15.18214")]
+[assembly: AssemblyVersion("2.4.18.18218")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/TFS/TeamFoundationServiceExtendedClient.cs b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/TFS/TeamFoundationServiceExtendedClient.cs
index 3828e7aed..6225e1480 100644
--- a/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/TFS/TeamFoundationServiceExtendedClient.cs
+++ b/Software/Visual_Studio/MachineStudio/Tango.MachineStudio.UI/TFS/TeamFoundationServiceExtendedClient.cs
@@ -86,7 +86,7 @@ namespace Tango.MachineStudio.UI.TFS
public async Task<WorkItem> CloseWorkItem(WorkItem workItem)
{
await SetWorkItemState(Project, workItem, State.Closed);
- var updated = await AddWorkItemComment(Project, workItem, GetUserTeamMember(), "Bug has been verified and closed by " + GetUserTeamMember().DisplayName + " (via Tango Software).");
+ var updated = await AddWorkItemComment(Project, workItem, GetUserTeamMember(), "Bug has been verified and closed by " + GetUserTeamMember().DisplayName + " (via Machine Studio).");
ResolvedWorkItems.Remove(workItem);
return updated;
}
@@ -94,7 +94,7 @@ namespace Tango.MachineStudio.UI.TFS
public async Task<WorkItem> ReactivateWorkItem(WorkItem workItem)
{
await SetWorkItemState(Project, workItem, State.New);
- var updated = await AddWorkItemComment(Project, workItem, GetUserTeamMember(), "Bug has been reactivated by " + GetUserTeamMember().DisplayName + " (via Tango Software).");
+ var updated = await AddWorkItemComment(Project, workItem, GetUserTeamMember(), "Bug has been reactivated by " + GetUserTeamMember().DisplayName + " (via Machine Studio).");
updated = await SetWorkItemAssignment(Project, updated, workItem.ResolvedBy);
ResolvedWorkItems.Remove(workItem);
return updated;
diff --git a/Software/Visual_Studio/SideChains/RealTimeGraphEx/Properties/AssemblyInfo.cs b/Software/Visual_Studio/SideChains/RealTimeGraphEx/Properties/AssemblyInfo.cs
index bf7fcf99f..75102be4c 100644
--- a/Software/Visual_Studio/SideChains/RealTimeGraphEx/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/SideChains/RealTimeGraphEx/Properties/AssemblyInfo.cs
@@ -51,5 +51,5 @@ using System.Windows;
// You can specify all the values or you can default the Build and Revision Numbers
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("1.0.14.1933")]
+[assembly: AssemblyVersion("1.0.15.1034")]
[assembly: AssemblyFileVersion("1.0.0.0")]
diff --git a/Software/Visual_Studio/SideChains/Tango.AutoComplete/Properties/AssemblyInfo.cs b/Software/Visual_Studio/SideChains/Tango.AutoComplete/Properties/AssemblyInfo.cs
index 4efd7eb72..17c46f230 100644
--- a/Software/Visual_Studio/SideChains/Tango.AutoComplete/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/SideChains/Tango.AutoComplete/Properties/AssemblyInfo.cs
@@ -49,5 +49,5 @@ using System.Windows.Markup;
// You can specify all the values or you can default the Build and Revision Numbers
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("1.0.14.1933")]
+[assembly: AssemblyVersion("1.0.15.1034")]
[assembly: AssemblyFileVersion("1.0.0.8")]
diff --git a/Software/Visual_Studio/Tango.BL/EntitiesExtensions/BrushStop.cs b/Software/Visual_Studio/Tango.BL/EntitiesExtensions/BrushStop.cs
index 098d7abad..25b9c1764 100644
--- a/Software/Visual_Studio/Tango.BL/EntitiesExtensions/BrushStop.cs
+++ b/Software/Visual_Studio/Tango.BL/EntitiesExtensions/BrushStop.cs
@@ -239,6 +239,15 @@ namespace Tango.BL.Entities
set { _outOfGamutChecked = value; RaisePropertyChangedAuto(); }
}
+ [NotMapped]
+ public double LiquidVolumesSum
+ {
+ get
+ {
+ return LiquidVolumes != null ? LiquidVolumes.Where(x => x.IdsPack.IdsPackFormula.Code != IdsPackFormulas.Lubricant.ToInt32()).Sum(x => x.Volume) : 0;
+ }
+ }
+
#endregion
#region Public Methods
@@ -276,6 +285,7 @@ namespace Tango.BL.Entities
private void LiquidVolume_VolumeChanged()
{
RaisePropertyChanged(nameof(IsLiquidVolumesOutOfRange));
+ RaisePropertyChanged(nameof(LiquidVolumesSum));
}
public double GetVolume(int packIndex)
diff --git a/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBlowerTypes.cs b/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBlowerTypes.cs
index 00edf80a8..1f2a3deec 100644
--- a/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBlowerTypes.cs
+++ b/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBlowerTypes.cs
@@ -20,10 +20,10 @@ namespace Tango.BL.Enumerations
{
/// <summary>
- /// (Standard Blower)
+ /// (Default Blower)
/// </summary>
- [Description("Standard Blower")]
- StandardBlower = 0,
+ [Description("Default Blower")]
+ DefaultBlower = 0,
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBreakSensorTypes.cs b/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBreakSensorTypes.cs
index 9ed516a25..4c539883c 100644
--- a/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBreakSensorTypes.cs
+++ b/Software/Visual_Studio/Tango.BL/Enumerations/HardwareBreakSensorTypes.cs
@@ -20,10 +20,10 @@ namespace Tango.BL.Enumerations
{
/// <summary>
- /// (Standard Break Sensor)
+ /// (Default Break Sensor)
/// </summary>
- [Description("Standard Break Sensor")]
- StandardBreakSensor = 0,
+ [Description("Default Break Sensor")]
+ DefaultBreakSensor = 0,
}
}
diff --git a/Software/Visual_Studio/Tango.BL/Enumerations/TechControllers.cs b/Software/Visual_Studio/Tango.BL/Enumerations/TechControllers.cs
index a9cf44874..bd7833725 100644
--- a/Software/Visual_Studio/Tango.BL/Enumerations/TechControllers.cs
+++ b/Software/Visual_Studio/Tango.BL/Enumerations/TechControllers.cs
@@ -26,6 +26,12 @@ namespace Tango.BL.Enumerations
Heater2Temp = 1,
/// <summary>
+ /// (Blower Voltage)
+ /// </summary>
+ [Description("Blower Voltage")]
+ BlowerVoltage = 2,
+
+ /// <summary>
/// (Heater 1 Temperature)
/// </summary>
[Description("Heater 1 Temperature")]
diff --git a/Software/Visual_Studio/Tango.BL/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.BL/Properties/AssemblyInfo.cs
index c8f631446..49a366cce 100644
--- a/Software/Visual_Studio/Tango.BL/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.BL/Properties/AssemblyInfo.cs
@@ -4,4 +4,4 @@ using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Business logic components")]
[assembly: ComVisible(false)]
-[assembly: AssemblyVersion("2.0.23.1933")] \ No newline at end of file
+[assembly: AssemblyVersion("2.0.25.1347")] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.CircularGauge/CircularGaugeControl.cs b/Software/Visual_Studio/Tango.CircularGauge/CircularGaugeControl.cs
index 7e8f1fa8c..f2068d713 100644
--- a/Software/Visual_Studio/Tango.CircularGauge/CircularGaugeControl.cs
+++ b/Software/Visual_Studio/Tango.CircularGauge/CircularGaugeControl.cs
@@ -61,6 +61,7 @@ namespace Tango.CircularGauge
private Double arcradius1;
private Double arcradius2;
private int animatingSpeedFactor = 6;
+ private List<FrameworkElement> _toClear;
#endregion
@@ -77,13 +78,18 @@ namespace Tango.CircularGauge
/// Dependency property to Get/Set the Minimum Value
/// </summary>
public static readonly DependencyProperty MinValueProperty =
- DependencyProperty.Register("MinValue", typeof(double), typeof(CircularGaugeControl), null);
+ DependencyProperty.Register("MinValue", typeof(double), typeof(CircularGaugeControl), new PropertyMetadata(0.0, (d, e) => (d as CircularGaugeControl).OnMinMaxChanged()));
/// <summary>
/// Dependency property to Get/Set the Maximum Value
/// </summary>
public static readonly DependencyProperty MaxValueProperty =
- DependencyProperty.Register("MaxValue", typeof(double), typeof(CircularGaugeControl), null);
+ DependencyProperty.Register("MaxValue", typeof(double), typeof(CircularGaugeControl), new PropertyMetadata(100.0, (d, e) => (d as CircularGaugeControl).OnMinMaxChanged()));
+
+ private void OnMinMaxChanged()
+ {
+ DrawScale();
+ }
/// <summary>
/// Dependency property to Get/Set the Radius of the gauge
@@ -895,6 +901,7 @@ namespace Tango.CircularGauge
public CircularGaugeControl()
{
+ _toClear = new List<FrameworkElement>();
_rangeIndicators = new List<Path>();
}
@@ -1128,15 +1135,19 @@ namespace Tango.CircularGauge
//Reset Pointer
MovePointer(ScaleStartAngle);
}
-
-
-
}
//Drawing the scale with the Scale Radius
private void DrawScale()
{
+ foreach (var item in _toClear)
+ {
+ rootGrid.Children.Remove(item);
+ }
+
+ _toClear.Clear();
+
//Calculate one major tick angle
Double majorTickUnitAngle = ScaleSweepAngle / MajorDivisionsCount;
@@ -1211,8 +1222,9 @@ namespace Tango.CircularGauge
majortickgp.Children.Add(majorticktt);
majortickrect.RenderTransform = majortickgp;
tb.RenderTransform = majorscalevaluett;
- rootGrid.Children.Add(majortickrect);
- rootGrid.Children.Add(tb);
+
+ AddToRootGrid(majortickrect);
+ AddToRootGrid(tb);
//Drawing the minor axis ticks
@@ -1247,7 +1259,7 @@ namespace Tango.CircularGauge
minortickgp.Children.Add(minorticktt);
mr.RenderTransform = minortickgp;
- rootGrid.Children.Add(mr);
+ AddToRootGrid(mr);
}
@@ -1425,11 +1437,20 @@ namespace Tango.CircularGauge
rangeIndicator.SetValue(Canvas.ZIndexProperty, 150);
// Adding the segment to the root grid
- rootGrid.Children.Add(rangeIndicator);
+ if (!rootGrid.Children.Contains(rangeIndicator))
+ {
+ rootGrid.Children.Add(rangeIndicator);
+ }
return rangeIndicator;
}
#endregion
+
+ private void AddToRootGrid(FrameworkElement element)
+ {
+ rootGrid.Children.Add(element);
+ _toClear.Add(element);
+ }
}
}
diff --git a/Software/Visual_Studio/Tango.CircularGauge/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.CircularGauge/Properties/AssemblyInfo.cs
index 58e9b0bf3..a3183ac9e 100644
--- a/Software/Visual_Studio/Tango.CircularGauge/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.CircularGauge/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Circular Gauge Control")]
-[assembly: AssemblyVersion("2.0.6.1407")]
+[assembly: AssemblyVersion("2.0.7.1347")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/Tango.CodeGeneration/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.CodeGeneration/Properties/AssemblyInfo.cs
index e414007e6..13ef2c4e3 100644
--- a/Software/Visual_Studio/Tango.CodeGeneration/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.CodeGeneration/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Code Generation Components")]
-[assembly: AssemblyVersion("2.0.11.1933")]
+[assembly: AssemblyVersion("2.0.12.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.ColorPicker/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.ColorPicker/Properties/AssemblyInfo.cs
index 65721e37d..e34a9f2b8 100644
--- a/Software/Visual_Studio/Tango.ColorPicker/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.ColorPicker/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Color Picker Control")]
-[assembly: AssemblyVersion("2.0.14.1933")]
+[assembly: AssemblyVersion("2.0.15.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/Tango.Core/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Core/Properties/AssemblyInfo.cs
index 9b419879d..794acfeef 100644
--- a/Software/Visual_Studio/Tango.Core/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Core/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Core Components")]
-[assembly: AssemblyVersion("2.0.23.1933")]
+[assembly: AssemblyVersion("2.0.24.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.DAL.Local/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.DAL.Local/Properties/AssemblyInfo.cs
index 38c0f9759..a1333931c 100644
--- a/Software/Visual_Studio/Tango.DAL.Local/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.DAL.Local/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Local Data Access Layer")]
-[assembly: AssemblyVersion("2.0.11.1933")]
+[assembly: AssemblyVersion("2.0.12.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.DAL.Remote/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.DAL.Remote/Properties/AssemblyInfo.cs
index 6bbd0fef8..f33c1f8ee 100644
--- a/Software/Visual_Studio/Tango.DAL.Remote/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.DAL.Remote/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Remote Data Access Layer")]
-[assembly: AssemblyVersion("2.0.22.1933")]
+[assembly: AssemblyVersion("2.0.23.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.DragAndDrop/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.DragAndDrop/Properties/AssemblyInfo.cs
index b64d314ba..edff0e8c7 100644
--- a/Software/Visual_Studio/Tango.DragAndDrop/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.DragAndDrop/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Drag & Drop Components")]
-[assembly: AssemblyVersion("2.0.20.1933")]
+[assembly: AssemblyVersion("2.0.21.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Editors/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Editors/Properties/AssemblyInfo.cs
index 6b32146e9..a2f38b0fe 100644
--- a/Software/Visual_Studio/Tango.Editors/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Editors/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Visual Diagram Editing Components")]
-[assembly: AssemblyVersion("2.0.14.1933")]
+[assembly: AssemblyVersion("2.0.15.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/Tango.Emulations/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Emulations/Properties/AssemblyInfo.cs
index 714659401..19a22963e 100644
--- a/Software/Visual_Studio/Tango.Emulations/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Emulations/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Emulation Components")]
-[assembly: AssemblyVersion("2.0.7.1608")]
+[assembly: AssemblyVersion("2.0.8.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Integration/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Integration/Properties/AssemblyInfo.cs
index 4ce708b53..fc3c0cf66 100644
--- a/Software/Visual_Studio/Tango.Integration/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Integration/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Logging Library")]
-[assembly: AssemblyVersion("2.0.21.1933")]
+[assembly: AssemblyVersion("2.0.22.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Logging/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Logging/Properties/AssemblyInfo.cs
index 0a578efca..b8012e703 100644
--- a/Software/Visual_Studio/Tango.Logging/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Logging/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Logging Library")]
-[assembly: AssemblyVersion("2.0.27.1933")]
+[assembly: AssemblyVersion("2.0.28.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.PMR/Common/ErrorCode.cs b/Software/Visual_Studio/Tango.PMR/Common/ErrorCode.cs
index 330c55868..92596a89d 100644
--- a/Software/Visual_Studio/Tango.PMR/Common/ErrorCode.cs
+++ b/Software/Visual_Studio/Tango.PMR/Common/ErrorCode.cs
@@ -22,14 +22,14 @@ namespace Tango.PMR.Common {
static ErrorCodeReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "Cg9FcnJvckNvZGUucHJvdG8SEFRhbmdvLlBNUi5Db21tb24q+AEKCUVycm9y",
+ "Cg9FcnJvckNvZGUucHJvdG8SEFRhbmdvLlBNUi5Db21tb24qiAIKCUVycm9y",
"Q29kZRIICgROT05FEAASEQoNR0VORVJBTF9FUlJPUhABEgsKB0JBRF9DUkMQ",
"AhIeChpJTlZBTElEX0RJR0lUQUxfUElOX05VTUJFUhADEhsKF1VOQVVUSE9S",
"SVpFRF9DT05ORUNUSU9OEAQSHwobQ09OVElOVU9VU19SRVNQT05TRV9BQk9S",
- "VEVEEAUSFgoRSU5WQUxJRF9VUExPQURfSUQQ6AcSEwoORklMRV9OT1RfRk9V",
- "TkQQ6QcSFwoSSU5WQUxJRF9QUk9DRVNTX0lEEOoHEh0KGEZJTEVfTEVOR1RI",
- "X09VVF9PRl9SQU5HRRDrB0IcChpjb20udHdpbmUudGFuZ28ucG1yLmNvbW1v",
- "bmIGcHJvdG8z"));
+ "VEVEEAUSDgoKSk9CX0ZBSUxFRBAGEhYKEUlOVkFMSURfVVBMT0FEX0lEEOgH",
+ "EhMKDkZJTEVfTk9UX0ZPVU5EEOkHEhcKEklOVkFMSURfUFJPQ0VTU19JRBDq",
+ "BxIdChhGSUxFX0xFTkdUSF9PVVRfT0ZfUkFOR0UQ6wdCHAoaY29tLnR3aW5l",
+ "LnRhbmdvLnBtci5jb21tb25iBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Common.ErrorCode), }, null));
@@ -57,6 +57,7 @@ namespace Tango.PMR.Common {
///Should be returned to a continuous response when aborted by the requesting client.
/// </summary>
[pbr::OriginalName("CONTINUOUS_RESPONSE_ABORTED")] ContinuousResponseAborted = 5,
+ [pbr::OriginalName("JOB_FAILED")] JobFailed = 6,
/// <summary>
///IO
/// </summary>
diff --git a/Software/Visual_Studio/Tango.PMR/Diagnostics/ValueComponent.cs b/Software/Visual_Studio/Tango.PMR/Diagnostics/ValueComponent.cs
index 88ba622ee..efd610aca 100644
--- a/Software/Visual_Studio/Tango.PMR/Diagnostics/ValueComponent.cs
+++ b/Software/Visual_Studio/Tango.PMR/Diagnostics/ValueComponent.cs
@@ -23,9 +23,9 @@ namespace Tango.PMR.Diagnostics {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
"ChRWYWx1ZUNvbXBvbmVudC5wcm90bxIVVGFuZ28uUE1SLkRpYWdub3N0aWNz",
- "KjIKDlZhbHVlQ29tcG9uZW50Eg8KC0hlYXRlcjFUZW1wEAASDwoLSGVhdGVy",
- "MlRlbXAQAUIhCh9jb20udHdpbmUudGFuZ28ucG1yLmRpYWdub3N0aWNzYgZw",
- "cm90bzM="));
+ "KkUKDlZhbHVlQ29tcG9uZW50Eg8KC0hlYXRlcjFUZW1wEAASDwoLSGVhdGVy",
+ "MlRlbXAQARIRCg1CbG93ZXJWb2x0YWdlEAJCIQofY29tLnR3aW5lLnRhbmdv",
+ "LnBtci5kaWFnbm9zdGljc2IGcHJvdG8z"));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Diagnostics.ValueComponent), }, null));
@@ -43,6 +43,10 @@ namespace Tango.PMR.Diagnostics {
///Heater 2 Temperature (Min = 0, Max = 100)
/// </summary>
[pbr::OriginalName("Heater2Temp")] Heater2Temp = 1,
+ /// <summary>
+ ///Blower Voltage (Min = 0, Max = 10000)
+ /// </summary>
+ [pbr::OriginalName("BlowerVoltage")] BlowerVoltage = 2,
}
#endregion
diff --git a/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBlowerType.cs b/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBlowerType.cs
index 24e1e612e..eae9c9809 100644
--- a/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBlowerType.cs
+++ b/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBlowerType.cs
@@ -23,8 +23,8 @@ namespace Tango.PMR.Hardware {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
"ChhIYXJkd2FyZUJsb3dlclR5cGUucHJvdG8SElRhbmdvLlBNUi5IYXJkd2Fy",
- "ZSooChJIYXJkd2FyZUJsb3dlclR5cGUSEgoOU3RhbmRhcmRCbG93ZXIQAEIe",
- "Chxjb20udHdpbmUudGFuZ28ucG1yLmhhcmR3YXJlYgZwcm90bzM="));
+ "ZSonChJIYXJkd2FyZUJsb3dlclR5cGUSEQoNRGVmYXVsdEJsb3dlchAAQh4K",
+ "HGNvbS50d2luZS50YW5nby5wbXIuaGFyZHdhcmViBnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Hardware.HardwareBlowerType), }, null));
@@ -35,9 +35,9 @@ namespace Tango.PMR.Hardware {
#region Enums
public enum HardwareBlowerType {
/// <summary>
- ///Standard Blower
+ ///Default Blower
/// </summary>
- [pbr::OriginalName("StandardBlower")] StandardBlower = 0,
+ [pbr::OriginalName("DefaultBlower")] DefaultBlower = 0,
}
#endregion
diff --git a/Software/Visual_Studio/Tango.PMR/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.PMR/Properties/AssemblyInfo.cs
index a58fdd179..7c462261f 100644
--- a/Software/Visual_Studio/Tango.PMR/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.PMR/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Protobuf Message Repository")]
-[assembly: AssemblyVersion("2.0.26.1933")]
+[assembly: AssemblyVersion("2.0.28.1347")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Protobuf/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Protobuf/Properties/AssemblyInfo.cs
index 07c88ce15..cefc51a37 100644
--- a/Software/Visual_Studio/Tango.Protobuf/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Protobuf/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Protobuf Components")]
-[assembly: AssemblyVersion("2.0.23.1933")]
+[assembly: AssemblyVersion("2.0.24.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Scripting/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Scripting/Properties/AssemblyInfo.cs
index 38561eac1..323d6dcbd 100644
--- a/Software/Visual_Studio/Tango.Scripting/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Scripting/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Roslyn Scripting Components")]
-[assembly: AssemblyVersion("2.0.20.1933")]
+[assembly: AssemblyVersion("2.0.21.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Serialization/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Serialization/Properties/AssemblyInfo.cs
index 395dcd0e0..acce511c1 100644
--- a/Software/Visual_Studio/Tango.Serialization/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Serialization/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Serialization Components")]
-[assembly: AssemblyVersion("2.0.22.1933")]
+[assembly: AssemblyVersion("2.0.23.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Settings/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Settings/Properties/AssemblyInfo.cs
index e0348e561..34ccc7166 100644
--- a/Software/Visual_Studio/Tango.Settings/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Settings/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Global Settings")]
-[assembly: AssemblyVersion("2.0.22.1933")]
+[assembly: AssemblyVersion("2.0.23.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.SharedUI/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.SharedUI/Properties/AssemblyInfo.cs
index 62e99366d..5651badea 100644
--- a/Software/Visual_Studio/Tango.SharedUI/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.SharedUI/Properties/AssemblyInfo.cs
@@ -5,7 +5,7 @@ using System.Runtime.InteropServices;
using System.Windows;
[assembly: AssemblyTitle("Tango - Shared UI Components")]
-[assembly: AssemblyVersion("2.0.20.1933")]
+[assembly: AssemblyVersion("2.0.21.1034")]
[assembly: ComVisible(false)]
diff --git a/Software/Visual_Studio/Tango.Synchronization/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Synchronization/Properties/AssemblyInfo.cs
index 4b2843ba3..4bf1ca1e6 100644
--- a/Software/Visual_Studio/Tango.Synchronization/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Synchronization/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - DataBase Synchronization Components")]
-[assembly: AssemblyVersion("2.0.11.1933")]
+[assembly: AssemblyVersion("2.0.12.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.TFS/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.TFS/Properties/AssemblyInfo.cs
index 835352a03..4bc907b9a 100644
--- a/Software/Visual_Studio/Tango.TFS/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.TFS/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - VSTS API Library")]
-[assembly: AssemblyVersion("2.0.13.1933")]
+[assembly: AssemblyVersion("2.0.14.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Transport/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Transport/Properties/AssemblyInfo.cs
index fad01fc39..a800f8c76 100644
--- a/Software/Visual_Studio/Tango.Transport/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Transport/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Transport Components")]
-[assembly: AssemblyVersion("2.0.21.1933")]
+[assembly: AssemblyVersion("2.0.22.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.Video/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Tango.Video/Properties/AssemblyInfo.cs
index 6f036d55f..f8805ac55 100644
--- a/Software/Visual_Studio/Tango.Video/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Tango.Video/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Video Components")]
-[assembly: AssemblyVersion("2.0.14.1933")]
+[assembly: AssemblyVersion("2.0.15.1034")]
[assembly: ComVisible(false)] \ No newline at end of file
diff --git a/Software/Visual_Studio/Utilities/Tango.ILMerge.UI/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Utilities/Tango.ILMerge.UI/Properties/AssemblyInfo.cs
index 7821ee49b..97ccd4c17 100644
--- a/Software/Visual_Studio/Utilities/Tango.ILMerge.UI/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Utilities/Tango.ILMerge.UI/Properties/AssemblyInfo.cs
@@ -44,4 +44,4 @@ using System.Windows;
// You can specify all the values or you can default the Build and Revision Numbers
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("2.0.7.1508")]
+[assembly: AssemblyVersion("2.0.10.1347")]
diff --git a/Software/Visual_Studio/Utilities/Tango.Stubs.Installer/Tango.Stubs.Installer.vdproj b/Software/Visual_Studio/Utilities/Tango.Stubs.Installer/Tango.Stubs.Installer.vdproj
index 7d89dacb4..ae035b019 100644
--- a/Software/Visual_Studio/Utilities/Tango.Stubs.Installer/Tango.Stubs.Installer.vdproj
+++ b/Software/Visual_Studio/Utilities/Tango.Stubs.Installer/Tango.Stubs.Installer.vdproj
@@ -58,43 +58,43 @@
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
+ "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
+ "OwnerKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_2DC8C87C2D90158064A700C697B49957"
- "OwnerKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
+ "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -112,25 +112,25 @@
"Entry"
{
"MsmKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
- "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
+ "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
- "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -142,7 +142,7 @@
"Entry"
{
"MsmKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
- "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -166,7 +166,7 @@
"Entry"
{
"MsmKey" = "8:_6290C6253BE08D5AEAF445DC538F5A32"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_8F0D060313A40E3D6C4B196C5819AA1F"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -178,7 +178,7 @@
"Entry"
{
"MsmKey" = "8:_6290C6253BE08D5AEAF445DC538F5A32"
- "OwnerKey" = "8:_8F0D060313A40E3D6C4B196C5819AA1F"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -196,13 +196,13 @@
"Entry"
{
"MsmKey" = "8:_65CE51F98CEBE9E3D46589DB414FAA93"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_65CE51F98CEBE9E3D46589DB414FAA93"
- "OwnerKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -220,19 +220,19 @@
"Entry"
{
"MsmKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
- "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
- "OwnerKey" = "8:_65F10524C176E1962250235480A84A48"
+ "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_65F10524C176E1962250235480A84A48"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -304,25 +304,25 @@
"Entry"
{
"MsmKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
- "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
+ "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
- "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -334,7 +334,7 @@
"Entry"
{
"MsmKey" = "8:_9E54529BF03690F97BEE24C45258265B"
- "OwnerKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -352,13 +352,13 @@
"Entry"
{
"MsmKey" = "8:_9E54529BF03690F97BEE24C45258265B"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_72B65244C4FF9BF01D372402C3CE52C5"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_9E54529BF03690F97BEE24C45258265B"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -382,25 +382,25 @@
"Entry"
{
"MsmKey" = "8:_B903CCAAE77F80B733B5FF7D00A8E88A"
- "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
+ "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_B903CCAAE77F80B733B5FF7D00A8E88A"
- "OwnerKey" = "8:_8B8BABD8173D326B3175B52925968439"
+ "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_B903CCAAE77F80B733B5FF7D00A8E88A"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_8B8BABD8173D326B3175B52925968439"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_B903CCAAE77F80B733B5FF7D00A8E88A"
- "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -430,13 +430,13 @@
"Entry"
{
"MsmKey" = "8:_BFCEC942CF3BF1B9FB6AEACA2A8753C3"
- "OwnerKey" = "8:_78C9B7DB89C8CFF3E6F812DBDAF18DC7"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_BFCEC942CF3BF1B9FB6AEACA2A8753C3"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -448,19 +448,19 @@
"Entry"
{
"MsmKey" = "8:_BFCEC942CF3BF1B9FB6AEACA2A8753C3"
- "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
+ "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_BFCEC942CF3BF1B9FB6AEACA2A8753C3"
- "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
+ "OwnerKey" = "8:_61BDC9339D1440BCBC454CC904BCE79C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_BFCEC942CF3BF1B9FB6AEACA2A8753C3"
- "OwnerKey" = "8:_61BDC9339D1440BCBC454CC904BCE79C"
+ "OwnerKey" = "8:_78C9B7DB89C8CFF3E6F812DBDAF18DC7"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -520,55 +520,55 @@
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
+ "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_B752AAD601735A1787F5E610419AB05C"
+ "OwnerKey" = "8:_6290C6253BE08D5AEAF445DC538F5A32"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_8F0D060313A40E3D6C4B196C5819AA1F"
+ "OwnerKey" = "8:_B752AAD601735A1787F5E610419AB05C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
+ "OwnerKey" = "8:_8F0D060313A40E3D6C4B196C5819AA1F"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_F35F069FCC8C9B6808AAD45B8039A4FB"
- "OwnerKey" = "8:_6290C6253BE08D5AEAF445DC538F5A32"
+ "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -586,49 +586,49 @@
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
+ "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
+ "OwnerKey" = "8:_6FEB8025486340DF9AA20A626115CC5C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
+ "OwnerKey" = "8:_61BDC9339D1440BCBC454CC904BCE79C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_8B8BABD8173D326B3175B52925968439"
+ "OwnerKey" = "8:_94CDF51D67BB69C2699CEC4485EBCA30"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_65F10524C176E1962250235480A84A48"
+ "OwnerKey" = "8:_7998F663E6A123C428ACD5825DA63527"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_E6DED22BB43E475B9794561C384D2713"
+ "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_61BDC9339D1440BCBC454CC904BCE79C"
+ "OwnerKey" = "8:_8B8BABD8173D326B3175B52925968439"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_92474495A2F0D65A21D2BFF4587358D8"
+ "OwnerKey" = "8:_65F10524C176E1962250235480A84A48"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -658,49 +658,49 @@
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_B752AAD601735A1787F5E610419AB05C"
+ "OwnerKey" = "8:_6290C6253BE08D5AEAF445DC538F5A32"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
+ "OwnerKey" = "8:_B752AAD601735A1787F5E610419AB05C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_431494AD14D6D56BB1D8134155637969"
+ "OwnerKey" = "8:_5917DC90155EF9A2065894D138595C1A"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_06C47D47C126843F16D4326EAD98A9F8"
+ "OwnerKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_21DE1D506BFDDE800A31513189A235A0"
+ "OwnerKey" = "8:_431494AD14D6D56BB1D8134155637969"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_D2FFB7AB335C92855094B6988900F58C"
+ "OwnerKey" = "8:_06C47D47C126843F16D4326EAD98A9F8"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_6290C6253BE08D5AEAF445DC538F5A32"
+ "OwnerKey" = "8:_21DE1D506BFDDE800A31513189A235A0"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
{
"MsmKey" = "8:_UNDEFINED"
- "OwnerKey" = "8:_5397E5B2CD05015FD556CF7136D97D21"
+ "OwnerKey" = "8:_D2FFB7AB335C92855094B6988900F58C"
"MsmSig" = "8:_UNDEFINED"
}
"Entry"
@@ -777,7 +777,7 @@
"DisplayName" = "8:Debug"
"IsDebugOnly" = "11:TRUE"
"IsReleaseOnly" = "11:FALSE"
- "OutputFilename" = "8:..\\..\\Build\\Debug\\Installers\\Tango Stubs Installer v3.1.msi"
+ "OutputFilename" = "8:..\\..\\Build\\Debug\\Installers\\Tango Stubs Installer v3.2.msi"
"PackageFilesAs" = "3:2"
"PackageFileSize" = "3:-2147483648"
"CabType" = "3:1"
@@ -899,7 +899,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Scripting, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Scripting, Version=2.0.21.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_0712ECEB4DE24D8B9E9936D94BDC61B4"
@@ -1018,7 +1018,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.PMR, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.PMR, Version=2.0.27.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_25CD57B9CA3242F18E33F548DDB13C14"
@@ -1111,7 +1111,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.PMR, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.PMR, Version=2.0.27.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_5397E5B2CD05015FD556CF7136D97D21"
@@ -1142,7 +1142,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.BL, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.BL, Version=2.0.24.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_5917DC90155EF9A2065894D138595C1A"
@@ -1173,7 +1173,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:StubsExecutionGUI, Version=3.1.0.0, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:StubsExecutionGUI, Version=3.2.3.1608, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_61BDC9339D1440BCBC454CC904BCE79C"
@@ -1204,7 +1204,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Scripting, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Scripting, Version=2.0.21.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_6290C6253BE08D5AEAF445DC538F5A32"
@@ -1297,7 +1297,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Stubs, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Stubs, Version=2.0.6.1407, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_6FEB8025486340DF9AA20A626115CC5C"
@@ -1359,7 +1359,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Settings, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Settings, Version=2.0.23.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_78C9B7DB89C8CFF3E6F812DBDAF18DC7"
@@ -1390,7 +1390,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Integration, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Integration, Version=2.0.22.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_7998F663E6A123C428ACD5825DA63527"
@@ -1421,7 +1421,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Serialization, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Serialization, Version=2.0.23.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_8B8BABD8173D326B3175B52925968439"
@@ -1452,7 +1452,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.SharedUI, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.SharedUI, Version=2.0.21.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_8F0D060313A40E3D6C4B196C5819AA1F"
@@ -1483,7 +1483,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Transport, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Transport, Version=2.0.22.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_92474495A2F0D65A21D2BFF4587358D8"
@@ -1514,7 +1514,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Stubs, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Stubs, Version=2.0.6.1407, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_94CDF51D67BB69C2699CEC4485EBCA30"
@@ -1607,7 +1607,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.DragAndDrop, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.DragAndDrop, Version=2.0.21.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_B752AAD601735A1787F5E610419AB05C"
@@ -1669,7 +1669,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Logging, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Logging, Version=2.0.28.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_BFCEC942CF3BF1B9FB6AEACA2A8753C3"
@@ -1731,7 +1731,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:ICSharpCode.AvalonEdit, Version=4.3.1.9429, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:ICSharpCode.AvalonEdit, Version=1.0.18.1933, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_D2FFB7AB335C92855094B6988900F58C"
@@ -1793,7 +1793,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:stubexec, Version=0.0.0.0, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:stubexec, Version=2.0.1.1407, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_E6DED22BB43E475B9794561C384D2713"
@@ -1855,7 +1855,7 @@
{
"AssemblyRegister" = "3:1"
"AssemblyIsInGAC" = "11:FALSE"
- "AssemblyAsmDisplayName" = "8:Tango.Core, Version=1.0.0.4, Culture=neutral, processorArchitecture=MSIL"
+ "AssemblyAsmDisplayName" = "8:Tango.Core, Version=2.0.24.1034, Culture=neutral, processorArchitecture=MSIL"
"ScatterAssemblies"
{
"_F35F069FCC8C9B6808AAD45B8039A4FB"
@@ -1938,15 +1938,15 @@
{
"Name" = "8:Microsoft Visual Studio"
"ProductName" = "8:Tango Stubs GUI"
- "ProductCode" = "8:{785D4E03-C4B7-4373-8011-F8A51ACC9EFA}"
- "PackageCode" = "8:{6E59A3AB-9096-4045-A0C1-7D6CD7BC721A}"
+ "ProductCode" = "8:{D61C13D5-FF5C-44AB-8091-0D226C732A0D}"
+ "PackageCode" = "8:{4BAD28C3-20FD-466E-8242-C23419D409D4}"
"UpgradeCode" = "8:{72B680FB-E47D-486A-A81E-6C035F2EBA42}"
"AspNetVersion" = "8:4.0.30319.0"
"RestartWWWService" = "11:FALSE"
"RemovePreviousVersions" = "11:TRUE"
"DetectNewerInstalledVersion" = "11:TRUE"
"InstallAllUsers" = "11:FALSE"
- "ProductVersion" = "8:3.1"
+ "ProductVersion" = "8:3.2"
"Manufacturer" = "8:Twine"
"ARPHELPTELEPHONE" = "8:"
"ARPHELPLINK" = "8:"
diff --git a/Software/Visual_Studio/Utilities/Tango.Stubs.UI/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Utilities/Tango.Stubs.UI/Properties/AssemblyInfo.cs
index afc6713b9..4251bcef5 100644
--- a/Software/Visual_Studio/Utilities/Tango.Stubs.UI/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Utilities/Tango.Stubs.UI/Properties/AssemblyInfo.cs
@@ -3,5 +3,5 @@ using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
[assembly: AssemblyTitle("Tango - Stubs execution GUI utility")]
-[assembly: AssemblyVersion("3.1.3.1608")]
+[assembly: AssemblyVersion("3.2.4.1347")]
diff --git a/Software/Visual_Studio/Utilities/Tango.UITests/Properties/AssemblyInfo.cs b/Software/Visual_Studio/Utilities/Tango.UITests/Properties/AssemblyInfo.cs
index a36373fe6..8e619f621 100644
--- a/Software/Visual_Studio/Utilities/Tango.UITests/Properties/AssemblyInfo.cs
+++ b/Software/Visual_Studio/Utilities/Tango.UITests/Properties/AssemblyInfo.cs
@@ -51,5 +51,5 @@ using System.Windows;
// You can specify all the values or you can default the Build and Revision Numbers
// by using the '*' as shown below:
// [assembly: AssemblyVersion("1.0.*")]
-[assembly: AssemblyVersion("1.0.8.1508")]
+[assembly: AssemblyVersion("1.0.11.1347")]
[assembly: AssemblyFileVersion("1.0.0.0")]
diff --git a/Software/PMR/Messages/Hardware/HardwareBreakSensorType.proto b/Software/PMR/Messages/Hardware/HardwareBreakSensorType.proto
index d286c3c67..f2a8948b4 100644
--- a/Software/PMR/Messages/Hardware/HardwareBreakSensorType.proto
+++ b/Software/PMR/Messages/Hardware/HardwareBreakSensorType.proto
@@ -16,7 +16,7 @@ option java_package = "com.twine.tango.pmr.hardware";
enum HardwareBreakSensorType
{
- //Standard Break Sensor
- StandardBreakSensor = 0;
+ //Default Break Sensor
+ DefaultBreakSensor = 0;
}
diff --git a/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBreakSensorType.cs b/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBreakSensorType.cs
index b831b5e19..489859ac9 100644
--- a/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBreakSensorType.cs
+++ b/Software/Visual_Studio/Tango.PMR/Hardware/HardwareBreakSensorType.cs
@@ -23,9 +23,9 @@ namespace Tango.PMR.Hardware {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
"Ch1IYXJkd2FyZUJyZWFrU2Vuc29yVHlwZS5wcm90bxISVGFuZ28uUE1SLkhh",
- "cmR3YXJlKjIKF0hhcmR3YXJlQnJlYWtTZW5zb3JUeXBlEhcKE1N0YW5kYXJk",
- "QnJlYWtTZW5zb3IQAEIeChxjb20udHdpbmUudGFuZ28ucG1yLmhhcmR3YXJl",
- "YgZwcm90bzM="));
+ "cmR3YXJlKjEKF0hhcmR3YXJlQnJlYWtTZW5zb3JUeXBlEhYKEkRlZmF1bHRC",
+ "cmVha1NlbnNvchAAQh4KHGNvbS50d2luZS50YW5nby5wbXIuaGFyZHdhcmVi",
+ "BnByb3RvMw=="));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Hardware.HardwareBreakSensorType), }, null));
@@ -36,9 +36,9 @@ namespace Tango.PMR.Hardware {
#region Enums
public enum HardwareBreakSensorType {
/// <summary>
///Standard Break Sensor
/// </summary>
- [pbr::OriginalName("StandardBreakSensor")] StandardBreakSensor = 0,
+ [pbr::OriginalName("DefaultBreakSensor")] DefaultBreakSensor = 0,
}
#endregion
@@ -36,9 +36,9 @@ namespace Tango.PMR.Hardware {
public enum HardwareBreakSensorType {
/// <summary>
- ///Standard Break Sensor
+ ///Default Break Sensor
/// </summary>